<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns="http://www.w3.org/1999/xhtml"> 

<xsl:output method="xhtml:xhtml"/>

<xsl:param name="pwd"/>
<xsl:variable name="zvonItemid" select="document('../frontpage.xml')/frontPage/@idref"/>
<xsl:variable name="examplesDoc" select="document('../examples.xml')/examples"/>



<xsl:template name="allRefs">
  <xsl:document href="{$pwd}Output/_allIndex.html">
    <html>
      <head>
        <title> TOC - DOM2 reference (everything) </title>
        <link href="global.css" rel="stylesheet" type="text/css" />
        <link href="reference.css" rel="stylesheet" type="text/css" />
        <link href="example.css" rel="stylesheet" type="text/css" />
      </head>
      <body>
        <!-- HEADER -->
        <xsl:call-template name="descriptionTop"/>
        <table width="100%" border="0" cellpadding="0" cellspacing="0" class="menu">
           <tr>
              <td class="right">
                <a class="menuH" href="_glossary.html">[Glossary]</a>&#160;
                <a class="menuH" href="_help.html">[Help]</a>&#160;&#160;&#160;
              </td>
           </tr>
        </table>
        <!-- ALL-REFS body -->
        <xsl:apply-templates select="." mode="allRefs"/>
        <!-- FOOTER -->
        <xsl:call-template name="footer"/>
      </body>
    </html>
  </xsl:document>
</xsl:template>

<xsl:template match="modules" mode="allRefs">
  <h2>Cross-module property and interface reference</h2>
  <table border="1" width="90%" align="center" style="empty-cells: show;">
  <tr>
    <th>property or interface</th>
    <th>DOM2 module</th>
    <th>example</th>
  </tr>
  <xsl:apply-templates select="descendant::interface | descendant::attribute | descendant::method" mode="allRefs">
    <xsl:sort select="@name"/>
  </xsl:apply-templates>
  </table>
</xsl:template>

<xsl:template match="interface | method | attribute" mode="allRefs">
  <!-- &#160;<span class="longName">[<xsl:value-of select="../@name"/>.<xsl:value-of select="@name"/>]</span> -->
  <xsl:variable name="path"><xsl:text>../Output/</xsl:text><xsl:value-of select="ancestor::module/@name"/><xsl:text>/</xsl:text></xsl:variable>
  <xsl:variable name="pathPlus">
    <xsl:choose>
      <xsl:when test="name()='interface'"><xsl:text></xsl:text></xsl:when>
      <xsl:when test="name()='attribute'"><xsl:value-of select="$path"/>attribute_<xsl:value-of select="@name"/>_<xsl:value-of select="../@name"/>.html</xsl:when>
      <xsl:when test="name()='method'"><xsl:value-of select="$path"/>method_<xsl:value-of select="@name"/>_<xsl:value-of select="../@name"/>.html</xsl:when>
      <xsl:otherwise/>
    </xsl:choose>
  </xsl:variable>
  <tr valign="middle">
    <td>
      <xsl:choose>
        <xsl:when test="name()='interface'">
          <a class="interface" href="{$path}interface_{@name}.html"><xsl:value-of select="@name"/></a>
        </xsl:when>
        <xsl:when test="name()='attribute'">
          <a class="attributeFg" href="{$pathPlus}" title="interface {../@name}"><xsl:value-of select="@name"/></a>&#160;<span class="longName">[<xsl:value-of select="../@name"/>.<xsl:value-of select="@name"/>]</span>
        </xsl:when>
        <xsl:when test="name()='method'">
          <a class="methodFg" href="{$pathPlus}" title="interface {../@name}"><xsl:value-of select="@name"/>()</a>&#160;<span class="longName">[<xsl:value-of select="../@name"/>.<xsl:value-of select="@name"/>]</span>
        </xsl:when>
      </xsl:choose>
    </td>
    <td align="center">
      <xsl:choose>
        <xsl:when test="ancestor::module/@name='Core'"><xsl:text>Core</xsl:text></xsl:when>
        <xsl:when test="ancestor::module/@name='HTML'"><xsl:text>HTML</xsl:text></xsl:when>
        <xsl:when test="ancestor::module/@name='Views'"><xsl:text>Views</xsl:text></xsl:when>
        <xsl:when test="ancestor::module/@name='Style'"><xsl:text>Style</xsl:text></xsl:when>
        <xsl:when test="ancestor::module/@name='Events'"><xsl:text>Events</xsl:text></xsl:when>
        <xsl:when test="ancestor::module/@name='TraversalRange'"><xsl:text>Traversal and Range</xsl:text></xsl:when>
        <xsl:otherwise/>
      </xsl:choose>
    </td>
    <td align="center">
      <xsl:if test="$examplesDoc//example[@forInterface=current()/parent::interface/@name and @forName=current()/@name]"><a href="{$pathPlus}#example">ex</a></xsl:if>
    </td>
  </tr>
</xsl:template>



</xsl:stylesheet>